import 'bootstrap.css';
import '@grapecity/wijmo.styles/wijmo.css';
import './styles.css';
//
import { Component, Inject, enableProdMode, NgModule, AfterViewInit, ViewChild } from '@angular/core';
import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
import { BrowserModule } from '@angular/platform-browser';
import { WjChartModule } from '@grapecity/wijmo.angular2.chart';
import { DataService } from './app.data';
import { AxisScrollbar } from './AxisScrollbar';
import * as wjChart from '@grapecity/wijmo.chart';
//
@Component({
    selector: 'app-component',
    templateUrl: 'src/app.component.html'
})
export class AppComponent implements AfterViewInit {
    data: any[];
    @ViewChild('theChart') theChart: wjChart.FlexChart;
    axisXScrollbar: AxisScrollbar;
    axisYScrollbar: AxisScrollbar;
    //
    constructor(@Inject(DataService) private dataService: DataService) {
        this.data = dataService.getData();
    }

    updateChart(s: wjChart.FlexChart) {
        s.itemsSource = this.dataService.getData1();
        // s.series[0].binding = 'date';
    }

    refreshChart(s: wjChart.FlexChart) {
        this.resetChartAxis(s);
    }
    //
    ngAfterViewInit() {
        this.createScrollbar();
        this.theChart.itemsSourceChanged.addHandler(this.refreshChart.bind(this));
    }

    resetChartAxis(chart: wjChart.FlexChart) {
        this.resetAxis(chart.axisX);
        this.resetAxis(chart.axisY);
    }

    resetAxis(axis: wjChart.Axis) {
        axis.min = undefined;
        axis.max = undefined;
    }

    createScrollbar() {
        this.axisXScrollbar = new AxisScrollbar(this.theChart.axisX, {
            minScale: 0.02
        });
    
        this.axisYScrollbar = new AxisScrollbar(this.theChart.axisY, {
            buttonsVisible: false,
            minScale: 0.05
        });
    }
}
//
@NgModule({
    imports: [WjChartModule, BrowserModule],
    declarations: [AppComponent],
    providers: [DataService],
    bootstrap: [AppComponent]
})
export class AppModule {
}
//
enableProdMode();
// Bootstrap application with hash style navigation and global services.
platformBrowserDynamic().bootstrapModule(AppModule);

